@@ -36,14 +36,34 @@ mod tests {
                         processes: vec![
                             Process {
                                 name: "loop1".to_string(),
-                                onsucceed: "loop2".to_string(),
-                                onfail: "loop3".to_string(),
+                                onsucceed: Some(Box::new(Process {
+                                    name: "loop2".to_string(),
+                                    onsucceed: None,
+                                    onfail: None,
+                                    silent: false,
+                                })),
+                                onfail: Some(Box::new(Process {
+                                    name: "loop3".to_string(),
+                                    onsucceed: None,
+                                    onfail: None,
+                                    silent: false,
+                                })),
                                 silent: true,
                             },
                             Process {
                                 name: "loop2".to_string(),
-                                onsucceed: "loop3".to_string(),
-                                onfail: "loop4".to_string(),
+                                onsucceed: Some(Box::new(Process {
+                                    name: "loop3".to_string(),
+                                    onsucceed: None,
+                                    onfail: None,
+                                    silent: false,
+                                })),
+                                onfail: Some(Box::new(Process {
+                                    name: "loop4".to_string(),
+                                    onsucceed: None,
+                                    onfail: None,
+                                    silent: false,
+                                })),
                                 silent: false,
                             },
                         ],
@@ -51,24 +71,39 @@ mod tests {
                     Task {
                         processes: vec![Process {
                             name: "loop3".to_string(),
-                            onsucceed: "loop4".to_string(),
-                            onfail: "loop5".to_string(),
+                            onsucceed: Some(Box::new(Process {
+                                name: "loop4".to_string(),
+                                onsucceed: None,
+                                onfail: None,
+                                silent: false,
+                            })),
+                            onfail: Some(Box::new(Process {
+                                name: "loop5".to_string(),
+                                onsucceed: None,
+                                onfail: None,
+                                silent: false,
+                            })),
                             silent: false,
                         }],
                     },
                     Task {
                         processes: vec![Process {
                             name: "loop6".to_string(),
-                            onsucceed: String::new(),
-                            onfail: String::new(),
+                            onsucceed: None,
+                            onfail: None,
                             silent: false,
                         }],
                     },
                     Task {
                         processes: vec![Process {
                             name: "loop7".to_string(),
-                            onsucceed: "loop8".to_string(),
-                            onfail: String::new(),
+                            onsucceed: Some(Box::new(Process {
+                                name: "loop8".to_string(),
+                                onsucceed: None,
+                                onfail: None,
+                                silent: false,
+                            })),
+                            onfail: None,
                             silent: true,
                         }],
                     },
